@@ -25,7 +25,8 @@ __all__ = [
     "ReceiverServer",
     "ReceiverWebSocket",
     "BaseReceiver",
-    "decode"
+    "decode",
+    "Receiver"
 ]
 
 def decode(data: bytes) -> ModelIO:
@@ -153,6 +154,11 @@ class ReceiverSocket(BaseReceiver, metaclass=ABCMeta):
             with controller.handler:
                 await self.handle(reader=reader, writer=writer)
 
+            if controller.handler.caught and controller.handler.exit:
+                controller.running = False
+
+                break
+
         if controller in self.controllers:
             self.controllers.remove(controller)
 
@@ -308,3 +314,15 @@ class ReceiverWebSocketServer(ReceiverWebSocket, ReceiverServer):
 
         async with self.server:
             await asyncio.Future()
+
+class Receiver:
+
+    class Socket:
+
+        Server = ReceiverSocketServer
+        Client = ReceiverSocketClient
+
+    class WebSocket:
+
+        Server = ReceiverWebSocketServer
+        Client = ReceiverWebSocketClient
