@@ -26,7 +26,8 @@ __all__ = [
     "SenderSocketClient",
     "SenderWebSocketServer",
     "SenderWebSocketClient",
-    "BaseSender"
+    "BaseSender",
+    "Sender"
 ]
 
 def encode(data: ModelIO) -> bytes:
@@ -117,6 +118,11 @@ class SenderServer(BaseSender, metaclass=ABCMeta):
                 with controller.handler:
                     await self.handle(**kwargs, data=data)
 
+                if controller.handler.caught and controller.handler.exit:
+                    controller.running = False
+
+                    break
+
         if queue in self.queues:
             self.queues.remove(queue)
 
@@ -388,3 +394,15 @@ class SenderWebSocketServer(SenderServer, SenderWebSocket):
 
         async with self.server:
             await asyncio.Future()
+
+class Sender:
+
+    class Socket:
+
+        Server = SenderSocketServer
+        Client = SenderSocketClient
+
+    class WebSocket:
+
+        Server = SenderWebSocketServer
+        Client = SenderWebSocketClient
